@@ -6,13 +6,6 @@
 ### see http://www.apache.org/licenses/LICENSE-2.0         ###
 ##############################################################
 
-from .Radiko import *
+from .Radiko import Radiko, RadikoException
 
-__copyright__    = "Copyright © 2020 kokarare1212 All rights reserved."
-__version__      = "1.2.1"
-__license__      = "Apache License 2.0"
-__author__       = "kokarare1212"
-__author_email__ = "kokarare1212@gmail.com"
-__url__          = "http://github.com/kokarare1212/Radiko/"
-
-__all__ = ["Radiko", "RadikoException"]
\ No newline at end of file
+__all__ = ["Radiko", "RadikoException"]
